# Kapchinsky ENVelope (KENV)
## Solver of the Kapchinsky-Vladimir envelope equation

<a href=mailto:fuodorov1998@gmail.com>V. Fedorov</a>, <a href=mailto:nikdanila@bk.ru>D. Nikiforov</a>, <a href=http://www.inp.nsk.su/~petrenko/>A. Petrenko</a>, (Novosibirsk, 2019)

## Overview

KENV is a solver code for the equation of the envelope of an electron beam with the Kapchinsky-Vladimirsky distribution for accelerator physics.

It is particularly suitable for accelerating an electron beam in direct channels with solenoidal and quadrupole focusing.

## Theory

Watch in theory_ru

## Algorithm

The algorithm reduces to lowering the order of the Kapchinsky-Vladimirsky differential equations to the first and subsequent integration.

## Language

KENV completely written in Python.

## Installation

```
pip install kenv
```

## Instruction

Watch notebooks: theory and example ...
